==> rca-precursor-0.1.27.tgz: package/src/components/UniversalRouter.js <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Route, Switch, withRouter } from 'react-router-dom';

import renderRoute from './renderRoute';
import { matchRoute, resolveInitialProps } from './../utils';

class UniversalRouter extends Component {
  static contextTypes = { router: PropTypes.any }
  static childContextTypes = { getRouteData: PropTypes.func.isRequired }

  constructor(props) {
    super(props);
    const { serverProps } = props;
    this.state = { ...serverProps };
  }

  getChildContext() {
    return {
      getRouteData: this.getRouteData,
    };
  }

  componentDidMount() {
    const { location, history } = this.props;
    this.fetchInitialProps(location);
    history.listen(this.fetchInitialProps);
  }

  getRouteData = path => (this.state[path])

  fetchInitialProps = async ({ pathname }) => {
    const { path, component } = matchRoute(this.props.routes, pathname);
    const cache = Boolean(component.cache);

    //  If state.cacheRoute is applied on the route component
    //  Only fetch the data once!
    if (!cache || !this.state.hasOwnProperty(pathname)) {
      const data = await resolveInitialProps(component, path, pathname);
      this.setState(Object.assign(this.state, { [pathname]: data }));
    }
  }

  render() {
    const { routes } = this.props;

    return (
      <Switch>
        {routes.map(({ path, component, ...rest }, index) => (
          <Route path={path} component={renderRoute(component)} key={index} {...rest} />
        ))}
      </Switch>
    );
  }
}

export default withRouter(UniversalRouter);

==> rca-precursor-0.1.54.tgz: package/src/components/UniversalRouter.js <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Route, Switch, withRouter } from 'react-router-dom';

import renderRoute from './renderRoute';
import { matchRoute, resolveInitialProps } from './../utils';

export class UniversalRouter extends Component {
  static contextTypes = { router: PropTypes.any }
  static childContextTypes = { getRouteData: PropTypes.func.isRequired }

  constructor(props) {
    super(props);
    const { serverProps } = props;
    this.state = { ...serverProps };
  }

  getChildContext = () => ({
    getRouteData: path => (this.state[path]),
  })

  componentDidMount() {
    const { location, history } = this.props;

    this.fetchInitialProps(location);
    history.listen(this.fetchInitialProps);
  }

  fetchInitialProps = async ({ pathname }) => {
    const { path, component } = matchRoute(this.props.routes, pathname);
    const cache = Boolean(component.cache);

    if (!cache || !this.state.hasOwnProperty(pathname)) {
      const data = await resolveInitialProps(component, path, pathname);
      this.setState(Object.assign(this.state, { [pathname]: data }));
    }
  }

  render() {
    const { routes } = this.props;

    return (
      <Switch>
        {routes.map(({ path, component, ...rest }) => (
          <Route
            key={path}
            path={path}
            component={renderRoute(component)}
            {...rest}
          />
        ))}
      </Switch>
    );
  }
}

export default withRouter(UniversalRouter);
